==> qore-json-module-1.8.tar.bz2: qore-json-module-1.8/docs/json/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore JSON Module", "index.html", [
    [ "Introduction", "index.html#jsonintro", null ],
    [ "Automatic JSON Serialization and Deserialization", "index.html#jsonserialization", null ],
    [ "JSON-RPC", "index.html#JSONRPC", null ],
    [ "Function and Method Tags", "index.html#codetags", [
      [ "NOOP", "index.html#NOOP", null ],
      [ "RUNTIME_NOOP", "index.html#RUNTIME_NOOP", null ],
      [ "RET_VALUE_ONLY", "index.html#RET_VALUE_ONLY", null ],
      [ "CONSTANT", "index.html#CONSTANT", null ],
      [ "DEPRECATED", "index.html#DEPRECATED", null ]
    ] ],
    [ "Release Notes", "index.html#jsonreleasenotes", [
      [ "Version 1.8", "index.html#v0_1_8", null ],
      [ "Version 1.7", "index.html#v0_1_7", null ],
      [ "Version 1.6", "index.html#v0_1_6", null ],
      [ "Version 1.5", "index.html#v0_1_5", null ],
      [ "Version 1.4", "index.html#v0_1_4", null ],
      [ "Version 1.3", "index.html#v0_1_3", null ],
      [ "Version 1.2", "index.html#v0_1_2", null ],
      [ "Version 1.1", "index.html#v0_1_1", null ],
      [ "Version 1.0", "index.html#v0_1_0", null ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-json-module-1.9.0.tar.bz2: qore-json-module-1.8.1/docs/json/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore JSON Module", "index.html", [
    [ "Introduction", "index.html#jsonintro", null ],
    [ "Automatic JSON Serialization and Deserialization", "index.html#jsonserialization", null ],
    [ "JSON-RPC", "index.html#JSONRPC", null ],
    [ "Function and Method Tags", "index.html#codetags", [
      [ "NOOP", "index.html#NOOP", null ],
      [ "RUNTIME_NOOP", "index.html#RUNTIME_NOOP", null ],
      [ "RET_VALUE_ONLY", "index.html#RET_VALUE_ONLY", null ],
      [ "CONSTANT", "index.html#CONSTANT", null ],
      [ "DEPRECATED", "index.html#DEPRECATED", null ]
    ] ],
    [ "Release Notes", "index.html#jsonreleasenotes", [
      [ "json Module Version 1.8.1", "index.html#json_v1_8_1", null ],
      [ "json Module Version 1.8", "index.html#json_v0_1_8", null ],
      [ "json Module Version 1.7", "index.html#json_v0_1_7", null ],
      [ "json Module Version 1.6", "index.html#json_v0_1_6", null ],
      [ "json Module Version 1.5", "index.html#json_v0_1_5", null ],
      [ "json Module Version 1.4", "index.html#json_v0_1_4", null ],
      [ "json Module Version 1.3", "index.html#json_v0_1_3", null ],
      [ "json Module Version 1.2", "index.html#json_v0_1_2", null ],
      [ "json Module Version 1.1", "index.html#json_v0_1_1", null ],
      [ "json Module Version 1.0", "index.html#json_v0_1_0", null ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
